@@ -25,6 +25,13 @@
 #define IS_LITTLE_ENDIAN (BYTEORDER == 0x1234 || BYTEORDER == 0x12345678)
 #define IS_64_BIT        (BYTEORDER > 0x10000)
 
+#define CONTROL_BYTE_MAJOR_TYPE_SHIFT 5
+
+#define _CONTROL_BYTE_LENGTH_MASK 0x1f
+
+#define CONTROL_BYTE_LENGTH_TYPE(byte) (((uint8_t) byte) & _CONTROL_BYTE_LENGTH_MASK)
+#define CONTROL_BYTE_MAJOR_TYPE(byte) (((uint8_t) byte) >> CONTROL_BYTE_MAJOR_TYPE_SHIFT)
+
 #define _croak croak
 
 /* Compatibility for 5.10.0 --------------------------------------------- */
@@ -62,15 +69,6 @@ union anyint {
     uint64_t u64;
 };
 
-union control_byte {
-    uint8_t u8;
-
-    struct {
-        unsigned int length_type : 5;
-        unsigned int major_type : 3;
-    } pieces;
-};
-
 #define _croak croak
 
 // I32 flags, char **argv
